==> countly-sdk-react-native-1.0.4.tgz: package/README.md <==

## What's Countly?
[Countly](http://count.ly) is an innovative, real-time, open source mobile analytics and push notifications platform. It collects data from mobile devices, and visualizes this information to analyze mobile application usage and end-user behavior. There are two parts of Countly: [the server that collects and analyzes data](http://github.com/countly/countly-server), and mobile SDK that sends this data. Both parts are open source with different licensing terms.

* **Slack user?** [Join our Slack community](http://slack.count.ly)
* **Questions?** [Ask in our Community forum](http://community.count.ly)

## About this SDK

This repository includes the Countly React Native SDK. See [Countly React Native SDK](http://resources.count.ly/docs/react-native) documentation for installation.

### Other Github resources ###

This SDK needs one of the following Countly Editions to work:

* Countly Community Edition, [downloadable from Github](https://github.com/Countly/countly-server).
* [Countly Enterprise Edition](http://count.ly/product), available for purchase.

For more information about Countly Enterprise Edition, see [comparison of different Countly Editions](https://count.ly/compare/)

There are also other Countly SDK repositories (both official and community supported) on [Countly Resources](http://resources.count.ly/v1.0/docs/downloading-sdks).

## Roadmap

* Push Notifications support

### How can I help you with your efforts?
Glad you asked. We need ideas, feedbacks and constructive comments. All your suggestions will be taken care with upmost importance. We are on [Twitter](http://twitter.com/gocountly) and [Facebook](http://www.facebook.com/Countly) if you would like to keep up with our fast progress!

If you liked Countly (just like we do!), [why not use one of our badges](https://count.ly/brand-assets/) and give a link back to us, so others know about this wonderful platform?

![Light badge](https://count.ly/wp-content/uploads/2014/10/countly_badge_5.png)  ![Dark badge](https://count.ly/wp-content/uploads/2014/10/countly_badge_6.png)

### Support

Have any questions? Visit [http://community.count.ly](http://community.count.ly "Countly Community Forum").

==> countly-sdk-react-native-3.0.0.tgz: package/README.md <==

## What's Countly?
[Countly](http://count.ly) is an innovative, real-time, open source mobile analytics and push notifications platform. It collects data from mobile devices, and visualizes this information to analyze mobile application usage and end-user behavior. There are two parts of Countly: [the server that collects and analyzes data](http://github.com/countly/countly-server), and mobile SDK that sends this data. Both parts are open source with different licensing terms.

* **Slack user?** [Join our Slack community](http://slack.count.ly)
* **Questions?** [Ask in our Community forum](http://community.count.ly)

## About this SDK

This repository includes the Countly React Native SDK. See [Countly React Native SDK](http://resources.count.ly/docs/react-native) documentation for installation.

## Other Github resources ##

This SDK needs one of the following Countly Editions to work:

* Countly Community Edition, [downloadable from Github](https://github.com/Countly/countly-server).
* [Countly Enterprise Edition](http://count.ly/product), available for purchase.

For more information about Countly Enterprise Edition, see [comparison of different Countly Editions](https://count.ly/compare/)

There are also other Countly SDK repositories (both official and community supported) on [Countly Resources](http://resources.count.ly/v1.0/docs/downloading-sdks).

## Roadmap ##

* DeviceID merging ([cross device reporting](https://resources.count.ly/docs/cross-device-reporting))
* Certificate pinning (SSL public key pinning)

## How can I help you with your efforts? ##

Glad you asked. We need ideas, feedbacks and constructive comments. All your suggestions will be taken care with upmost importance. We are on [Twitter](http://twitter.com/gocountly) and [Facebook](http://www.facebook.com/Countly) if you would like to keep up with our fast progress!

## Badges ##

If you like Countly, [why not use one of our badges](https://count.ly/brand-assets) and give a link back to us, so others know about this wonderful platform? 

<a href="https://count.ly/f/badge" rel="nofollow"><img style="width:145px;height:60px" src="https://count.ly/badges/dark.svg" alt="Countly - Product Analytics" /></a>

    <a href="https://count.ly/f/badge" rel="nofollow"><img style="width:145px;height:60px" src="https://count.ly/badges/dark.svg" alt="Countly - Product Analytics" /></a>

<a href="https://count.ly/f/badge" rel="nofollow"><img style="width:145px;height:60px" src="https://count.ly/badges/light.svg" alt="Countly - Product Analytics" /></a>

    <a href="https://count.ly/f/badge" rel="nofollow"><img style="width:145px;height:60px" src="https://count.ly/badges/light.svg" alt="Countly - Product Analytics" /></a>

## Support ##

Have any questions? Visit [http://community.count.ly](http://community.count.ly "Countly Community Forum").
